package com.op.system.api;


import com.op.common.core.domain.BaseFileData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import com.op.common.core.constant.SecurityConstants;
import com.op.common.core.constant.ServiceNameConstants;
import com.op.common.core.domain.R;
import com.op.system.api.domain.SysUser;
import com.op.system.api.factory.RemoteUserFallbackFactory;
import com.op.system.api.model.LoginUser;

import java.util.List;
import java.util.Map;

/**
 * 用户服务
 *
 * @author OP
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService {
	/**
	 * 通过用户名查询用户信息
	 *
	 * @param username 用户名
	 * @param source   请求来源
	 * @return 结果
	 */
	@GetMapping("/user/info/{username}")
	public R<LoginUser> getUserInfo(@PathVariable("username") String username,
			@RequestHeader(SecurityConstants.FROM_SOURCE) String source);

	/**
	 * 注册用户信息
	 *
	 * @param sysUser 用户信息
	 * @param source  请求来源
	 * @return 结果
	 */
	@PostMapping("/user/register")
	public R<Boolean> registerUserInfo(@RequestBody SysUser sysUser,
			@RequestHeader(SecurityConstants.FROM_SOURCE) String source);

	@PostMapping("/file/upLoadFile")
	public R<Boolean> upLoadFile(@RequestBody List<BaseFileData> files);

	/**
	 * 获取可见数据源
	 * @param user
	 * @return
	 */
	@PostMapping("/user/getPoolNameList")
	public R<List<Map<String, String>>> getPoolNameList(@RequestBody SysUser user);
}
