package com.op.system.api.factory;

import com.op.common.core.domain.BaseFileData;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;
import com.op.common.core.domain.R;
import com.op.system.api.RemoteUserService;
import com.op.system.api.domain.SysUser;
import com.op.system.api.model.LoginUser;

import java.util.List;
import java.util.Map;

/**
 * 用户服务降级处理
 *
 * @author OP
 */
@Component
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService> {
	private static final Logger log = LoggerFactory.getLogger(RemoteUserFallbackFactory.class);

	@Override
	public RemoteUserService create(Throwable throwable) {
		log.error("用户服务调用失败:{}", throwable.getMessage());
		return new RemoteUserService() {
			@Override
			public R<LoginUser> getUserInfo(String username, String source) {
				return R.fail("获取用户失败:" + throwable.getMessage());
			}

			@Override
			public R<Boolean> registerUserInfo(SysUser sysUser, String source) {
				return R.fail("注册用户失败:" + throwable.getMessage());
			}

			@Override
			public R<Boolean> upLoadFile(List<BaseFileData> files) {
				return R.fail("上传失败:" + throwable.getMessage());
			}

			@Override
			public R<List<Map<String, String>>> getPoolNameList(SysUser user) {
				return R.fail("工厂数据源获取失败:" + throwable.getMessage());
			}
		};
	}
}
