package com.op.mes.service.impl;

import java.util.List;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.op.common.core.utils.DateUtils;
import com.op.common.core.utils.uuid.IdUtils;
import com.op.mes.domain.ProProcessContent;
import com.op.mes.mapper.ProProcessContentMapper;
import com.op.mes.service.IProProcessContentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 生产工序内容Service业务层处理
 *
 * @author yinjinlu
 * @date 2022-05-12
 */
@Service
public class ProProcessContentServiceImpl implements IProProcessContentService
{
    @Autowired
    private ProProcessContentMapper proProcessContentMapper;

    /**
     * 查询生产工序内容
     *
     * @param contentId 生产工序内容主键
     * @return 生产工序内容
     */
    @Override
    @DS("#header.poolName")
    public ProProcessContent selectProProcessContentByContentId(String contentId)
    {
        return proProcessContentMapper.selectProProcessContentByContentId(contentId);
    }

    /**
     * 查询生产工序内容列表
     *
     * @param proProcessContent 生产工序内容
     * @return 生产工序内容
     */
    @Override
    @DS("#header.poolName")
    public List<ProProcessContent> selectProProcessContentList(ProProcessContent proProcessContent)
    {
        return proProcessContentMapper.selectProProcessContentList(proProcessContent);
    }

    /**
     * 新增生产工序内容
     *
     * @param proProcessContent 生产工序内容
     * @return 结果
     */
    @Override
    @DS("#header.poolName")
    public int insertProProcessContent(ProProcessContent proProcessContent)
    {
        proProcessContent.setCreateTime(DateUtils.getNowDate());
        proProcessContent.setContentId(IdUtils.fastSimpleUUID());
        return proProcessContentMapper.insertProProcessContent(proProcessContent);
    }

    /**
     * 修改生产工序内容
     *
     * @param proProcessContent 生产工序内容
     * @return 结果
     */
    @Override
    @DS("#header.poolName")
    public int updateProProcessContent(ProProcessContent proProcessContent)
    {
        proProcessContent.setUpdateTime(DateUtils.getNowDate());
        return proProcessContentMapper.updateProProcessContent(proProcessContent);
    }

    /**
     * 批量删除生产工序内容
     *
     * @param contentIds 需要删除的生产工序内容主键
     * @return 结果
     */
    @Override
    @DS("#header.poolName")
    public int deleteProProcessContentByContentIds(String[] contentIds)
    {
        return proProcessContentMapper.deleteProProcessContentByContentIds(contentIds);
    }

    /**
     * 删除生产工序内容信息
     *
     * @param contentId 生产工序内容主键
     * @return 结果
     */
    @Override
    @DS("#header.poolName")
    public int deleteProProcessContentByContentId(String contentId)
    {
        return proProcessContentMapper.deleteProProcessContentByContentId(contentId);
    }
}
