package com.op.system.controller;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import com.op.system.api.RemoteFileService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.op.common.core.constant.CacheConstants;
import com.op.common.core.utils.StringUtils;
import com.op.common.core.web.controller.BaseController;
import com.op.common.core.web.domain.AjaxResult;
import com.op.common.core.web.page.TableDataInfo;
import com.op.common.log.annotation.Log;
import com.op.common.log.enums.BusinessType;
import com.op.common.redis.service.RedisService;
import com.op.common.security.annotation.RequiresPermissions;
import com.op.system.api.model.LoginUser;
import com.op.system.domain.SysUserOnline;
import com.op.system.service.ISysUserOnlineService;

/**
 * 在线用户监控
 *
 * @author OP
 */
@RestController
@RequestMapping("/online")
public class SysUserOnlineController extends BaseController {
	@Autowired
	private ISysUserOnlineService userOnlineService;

	@Autowired
	private RedisService redisService;
	@Autowired
	private RemoteFileService remoteFileService;

	@RequiresPermissions("monitor:online:list")
	@GetMapping("/list")
	public TableDataInfo list(String ipaddr, String userName) {
		Collection<String> keys = redisService.keys(CacheConstants.LOGIN_TOKEN_KEY + "*");
		List<SysUserOnline> userOnlineList = new ArrayList<SysUserOnline>();
		for (String key : keys) {
			LoginUser user = redisService.getCacheObject(key);
			if (StringUtils.isNotEmpty(ipaddr) && StringUtils.isNotEmpty(userName)) {
				userOnlineList.add(userOnlineService.selectOnlineByInfo(ipaddr, userName, user));
			} else if (StringUtils.isNotEmpty(ipaddr)) {
				userOnlineList.add(userOnlineService.selectOnlineByIpaddr(ipaddr, user));
			} else if (StringUtils.isNotEmpty(userName)) {
				userOnlineList.add(userOnlineService.selectOnlineByUserName(userName, user));
			} else {
				userOnlineList.add(userOnlineService.loginUserToUserOnline(user));
			}
		}
		Collections.reverse(userOnlineList);
		userOnlineList.removeAll(Collections.singleton(null));
		return getDataTable(userOnlineList);
	}

	/**
	 * 强退用户
	 */
	@RequiresPermissions("monitor:online:forceLogout")
	@Log(title = "在线用户", businessType = BusinessType.FORCE)
	@DeleteMapping("/{tokenId}")
	public AjaxResult forceLogout(@PathVariable String tokenId) {
		redisService.deleteObject(CacheConstants.LOGIN_TOKEN_KEY + tokenId);
		return success();
	}

	@GetMapping("/{id}")
	public InputStream list(@PathVariable String id) {
		return remoteFileService.getFile(id);
	}
}
