package com.op.wms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.op.common.log.annotation.Log;
import com.op.common.log.enums.BusinessType;
import com.op.common.security.annotation.RequiresPermissions;
import com.op.wms.domain.BaseLocation;
import com.op.wms.service.IBaseLocationService;
import com.op.common.core.web.controller.BaseController;
import com.op.common.core.web.domain.AjaxResult;
import com.op.common.core.utils.poi.ExcelUtil;
import com.op.common.core.web.page.TableDataInfo;

/**
 * 货位管理Controller
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/location")
public class BaseLocationController extends BaseController {
	@Autowired
	private IBaseLocationService baseLocationService;

	/**
	 * 查询货位管理列表
	 */
	@RequiresPermissions("wms:location:list")
	@GetMapping("/list")
	public TableDataInfo list(BaseLocation baseLocation) {
		startPage();
		List<BaseLocation> list = baseLocationService.selectBaseLocationList(baseLocation);
		return getDataTable(list);
	}

	/**
	 * 导出货位管理列表
	 */
	@RequiresPermissions("wms:location:export")
	@Log(title = "货位管理", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, BaseLocation baseLocation) {
		List<BaseLocation> list = baseLocationService.selectBaseLocationList(baseLocation);
		ExcelUtil<BaseLocation> util = new ExcelUtil<BaseLocation>(BaseLocation.class);
		util.exportExcel(response, list, "货位管理数据");
	}

	/**
	 * 获取货位管理详细信息
	 */
	@RequiresPermissions("wms:location:query")
	@GetMapping(value = "/{locationId}")
	public AjaxResult getInfo(@PathVariable("locationId") String locationId) {
		return success(baseLocationService.selectBaseLocationByLocationId(locationId));
	}

	/**
	 * 新增货位管理
	 */
	@RequiresPermissions("wms:location:add")
	@Log(title = "货位管理", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody BaseLocation baseLocation) {
		return toAjax(baseLocationService.insertBaseLocation(baseLocation));
	}

	/**
	 * 修改货位管理
	 */
	@RequiresPermissions("wms:location:edit")
	@Log(title = "货位管理", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody BaseLocation baseLocation) {
		return toAjax(baseLocationService.updateBaseLocation(baseLocation));
	}

	/**
	 * 删除货位管理
	 */
	@RequiresPermissions("wms:location:remove")
	@Log(title = "货位管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{locationIds}")
	public AjaxResult remove(@PathVariable String[] locationIds) {
		return toAjax(baseLocationService.deleteBaseLocationByLocationIds(locationIds));
	}
}
