package com.op.wms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.op.common.log.annotation.Log;
import com.op.common.log.enums.BusinessType;
import com.op.common.security.annotation.RequiresPermissions;
import com.op.wms.domain.OdsInventoryOrder;
import com.op.wms.service.IOdsInventoryOrderService;
import com.op.common.core.web.controller.BaseController;
import com.op.common.core.web.domain.AjaxResult;
import com.op.common.core.utils.poi.ExcelUtil;
import com.op.common.core.web.page.TableDataInfo;

/**
 * 包材盘点单Controller
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/Inventoryorder")
public class OdsInventoryOrderController extends BaseController {
	@Autowired
	private IOdsInventoryOrderService odsInventoryOrderService;

	/**
	 * 查询包材盘点单列表
	 */
	@RequiresPermissions("wms:Inventoryorder:list")
	@GetMapping("/list")
	public TableDataInfo list(OdsInventoryOrder odsInventoryOrder) {
		startPage();
		List<OdsInventoryOrder> list = odsInventoryOrderService.selectOdsInventoryOrderList(odsInventoryOrder);
		return getDataTable(list);
	}

	/**
	 * 导出包材盘点单列表
	 */
	@RequiresPermissions("wms:Inventoryorder:export")
	@Log(title = "包材盘点单", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, OdsInventoryOrder odsInventoryOrder) {
		List<OdsInventoryOrder> list = odsInventoryOrderService.selectOdsInventoryOrderList(odsInventoryOrder);
		ExcelUtil<OdsInventoryOrder> util = new ExcelUtil<OdsInventoryOrder>(OdsInventoryOrder.class);
		util.exportExcel(response, list, "包材盘点单数据");
	}

	/**
	 * 获取包材盘点单详细信息
	 */
	@RequiresPermissions("wms:Inventoryorder:query")
	@GetMapping(value = "/{ID}")
	public AjaxResult getInfo(@PathVariable("ID") String ID) {
		return success(odsInventoryOrderService.selectOdsInventoryOrderByID(ID));
	}

	/**
	 * 新增包材盘点单
	 */
	@RequiresPermissions("wms:Inventoryorder:add")
	@Log(title = "包材盘点单", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody OdsInventoryOrder odsInventoryOrder) {
		return toAjax(odsInventoryOrderService.insertOdsInventoryOrder(odsInventoryOrder));
	}

	/**
	 * 修改包材盘点单
	 */
	@RequiresPermissions("wms:Inventoryorder:edit")
	@Log(title = "包材盘点单", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody OdsInventoryOrder odsInventoryOrder) {
		return toAjax(odsInventoryOrderService.updateOdsInventoryOrder(odsInventoryOrder));
	}

	/**
	 * 删除包材盘点单
	 */
	@RequiresPermissions("wms:Inventoryorder:remove")
	@Log(title = "包材盘点单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
	public AjaxResult remove(@PathVariable String[] IDs) {
		return toAjax(odsInventoryOrderService.deleteOdsInventoryOrderByIDs(IDs));
	}
}
