package com.op.wms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.op.common.log.annotation.Log;
import com.op.common.log.enums.BusinessType;
import com.op.common.security.annotation.RequiresPermissions;
import com.op.wms.domain.OdsWhiteEmbryo;
import com.op.wms.service.IOdsWhiteEmbryoService;
import com.op.common.core.web.controller.BaseController;
import com.op.common.core.web.domain.AjaxResult;
import com.op.common.core.utils.poi.ExcelUtil;
import com.op.common.core.web.page.TableDataInfo;

/**
 * 白胚出库单Controller
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/embryo")
public class OdsWhiteEmbryoController extends BaseController {
	@Autowired
	private IOdsWhiteEmbryoService odsWhiteEmbryoService;

	/**
	 * 查询白胚出库单列表
	 */
	@RequiresPermissions("wms:embryo:list")
	@GetMapping("/list")
	public TableDataInfo list(OdsWhiteEmbryo odsWhiteEmbryo) {
		startPage();
		List<OdsWhiteEmbryo> list = odsWhiteEmbryoService.selectOdsWhiteEmbryoList(odsWhiteEmbryo);
		return getDataTable(list);
	}

	/**
	 * 导出白胚出库单列表
	 */
	@RequiresPermissions("wms:embryo:export")
	@Log(title = "白胚出库单", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, OdsWhiteEmbryo odsWhiteEmbryo) {
		List<OdsWhiteEmbryo> list = odsWhiteEmbryoService.selectOdsWhiteEmbryoList(odsWhiteEmbryo);
		ExcelUtil<OdsWhiteEmbryo> util = new ExcelUtil<OdsWhiteEmbryo>(OdsWhiteEmbryo.class);
		util.exportExcel(response, list, "白胚出库单数据");
	}

	/**
	 * 获取白胚出库单详细信息
	 */
	@RequiresPermissions("wms:embryo:query")
	@GetMapping(value = "/{ID}")
	public AjaxResult getInfo(@PathVariable("ID") String ID) {
		return success(odsWhiteEmbryoService.selectOdsWhiteEmbryoByID(ID));
	}

	/**
	 * 新增白胚出库单
	 */
	@RequiresPermissions("wms:embryo:add")
	@Log(title = "白胚出库单", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody OdsWhiteEmbryo odsWhiteEmbryo) {
		return toAjax(odsWhiteEmbryoService.insertOdsWhiteEmbryo(odsWhiteEmbryo));
	}

	/**
	 * 修改白胚出库单
	 */
	@RequiresPermissions("wms:embryo:edit")
	@Log(title = "白胚出库单", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody OdsWhiteEmbryo odsWhiteEmbryo) {
		return toAjax(odsWhiteEmbryoService.updateOdsWhiteEmbryo(odsWhiteEmbryo));
	}

	/**
	 * 删除白胚出库单
	 */
	@RequiresPermissions("wms:embryo:remove")
	@Log(title = "白胚出库单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
	public AjaxResult remove(@PathVariable String[] IDs) {
		return toAjax(odsWhiteEmbryoService.deleteOdsWhiteEmbryoByIDs(IDs));
	}
}
