package com.op.wms.service.impl;

import java.util.List;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.op.common.core.utils.DateUtils;
import com.op.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.op.wms.mapper.BaseShiftsTMapper;
import com.op.wms.domain.BaseShiftsT;
import com.op.wms.service.IBaseShiftsTService;

/**
 * 班次管理Service业务层处理
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@Service
public class BaseShiftsTServiceImpl implements IBaseShiftsTService {
	@Autowired
	private BaseShiftsTMapper baseShiftsTMapper;

	/**
	 * 查询班次管理
	 * 
	 * @param shiftId 班次管理主键
	 * @return 班次管理
	 */
	@Override
	@DS("#header.poolName")
	public BaseShiftsT selectBaseShiftsTByShiftId(String shiftId) {
		return baseShiftsTMapper.selectBaseShiftsTByShiftId(shiftId);
	}

	/**
	 * 查询班次管理列表
	 * 
	 * @param baseShiftsT 班次管理
	 * @return 班次管理
	 */
	@Override
	@DS("#header.poolName")
	public List<BaseShiftsT> selectBaseShiftsTList(BaseShiftsT baseShiftsT) {
		return baseShiftsTMapper.selectBaseShiftsTList(baseShiftsT);
	}

	/**
	 * 新增班次管理
	 * 
	 * @param baseShiftsT 班次管理
	 * @return 结果
	 */
	@Override
	@DS("#header.poolName")
	public int insertBaseShiftsT(BaseShiftsT baseShiftsT) {
		baseShiftsT.setCreateDate(DateUtils.getNowDate());
		baseShiftsT.setUpdateBy(SecurityUtils.getUsername());
		return baseShiftsTMapper.insertBaseShiftsT(baseShiftsT);
	}

	/**
	 * 修改班次管理
	 * 
	 * @param baseShiftsT 班次管理
	 * @return 结果
	 */
	@Override
	@DS("#header.poolName")
	public int updateBaseShiftsT(BaseShiftsT baseShiftsT) {
		baseShiftsT.setLastUpdateDate(DateUtils.getNowDate());
		baseShiftsT.setLastUpdateBy(SecurityUtils.getUsername());
		return baseShiftsTMapper.updateBaseShiftsT(baseShiftsT);
	}

	/**
	 * 批量删除班次管理
	 * 
	 * @param shiftIds 需要删除的班次管理主键
	 * @return 结果
	 */
	@Override
	@DS("#header.poolName")
	public int deleteBaseShiftsTByShiftIds(String[] shiftIds) {
		return baseShiftsTMapper.deleteBaseShiftsTByShiftIds(shiftIds);
	}

	/**
	 * 删除班次管理信息
	 * 
	 * @param shiftId 班次管理主键
	 * @return 结果
	 */
	@Override
	@DS("#header.poolName")
	public int deleteBaseShiftsTByShiftId(String shiftId) {
		return baseShiftsTMapper.deleteBaseShiftsTByShiftId(shiftId);
	}
}
